% wa1500
% Version 2.0 15-Apr-2015
% 
% Summary
%     Matlab driver to communicate with Burleigh WA-1500 wavemeter via
%     RS-232.
%
% Description
%     The wa1500 toolbox allows communication to a Burleigh WA-1500
%     wavemeter via an RS-232 connection. Wavemeter communication can be
%     initialized and read out digitally. The analog output can be read and
%     converted to a wavelength in the software. The toolbox includes
%     functionality to send serial commands to the wavemeter.
%
%     The package documentation can be opened by typing
%
%       >> doc wa1500
%
%     into a matlab prompt.
%
% Setup
%     The serial cable should be plugged into the 'COM1' port of the
%     machine. A different serial port can be used by modifying the
%     wa_initialize function. This allows matlab to communicate with the
%     instrument using the SERIAL and FPRINTF functions.
%
%     Reading the wavelength using the analog output results in a faster
%     read time. However, to do this directly into matlab requires the data
%     acquisition toolbox and a DAQ board.
%
%
% WA1500 main functions.
%     wa_readWavelength - Get a single wavelength measurement
%     wa_findInstrument - get the wa1500 serial instrument
%     wa_close - Shut down communication to wavemeter
%     wa_command - send serial commands to wavemeter
%     wa_getInstrumentStatus - get current operating status of wavemeter
%     wa_initialize -  Initializes communcication to WA-1500 wavemeter
%     wa_testCommunication - test communcication to WA-1500 wavemeter
%     wa_volts2nm - Convert analog out voltage to wavelength
%     wa_waitForSettle - wait for laser wavelength to settle
%     wa_getSetPoint -  returns the current set point
%     wa_resetDeviation - Set the setpoint equal to current wavelength
%     wa_devResetQ - does the deviation need to be reset?
%     wa_getReading - get the text reading from wavemeter
%
% Others.
%     INSTALL, LICENSE, README, Burleigh WA-1500 manual.
%
%
%
%   Copyright (C) 2012 Todd Karin <toddakarin (at) gmail (dot) com>
%   Contributions by Pasqual Rivera
%   $Revision: 1.0 $Date: 2012/09/01 16:15:30 $

% Tags
%   Burleigh, WA-1500, WA1500, wavemeter, RS-232, serial, driver, reader, read