%wa_getInstrumentStatus - get current operating status of wavemeter
%
% data = wa_getInstrumentStatus() returns the current operating status of
% the wavemeter.
%
% Todd Karin
% 12/09/2014

function data = wa_getInstrumentStatus()

wa1500 = wa_findInstrument;
info = wa_getReading(wa1500);


data.mediumAir = readBitReturn('0100');
data.mediumVacuum =  readBitReturn('0200');
data.unitsNm = readBitReturn('0009');
data.unitsInvcm = readBitReturn('0012');
data.unitsGHz = readBitReturn('0024');
data.displayWavelength = readBitReturn('0040');
data.displayDeviation = readBitReturn('0080');
data.resolutionFixed = readBitReturn('0400');
data.resolutionAuto = readBitReturn('0800');
data.averagingOn = readBitReturn('1000');
data.averagingOff = readBitReturn('2000');
data.displayRes = readBitReturn('0001');
data.setPoint = readBitReturn('0002');

data.numAveraged = readBitReturn('0004');
data.analogRes = readBitReturn('0008');
data.pressure = readBitReturn('0010');
data.temperature = readBitReturn('0020');
data.humidity = readBitReturn('0040');
data.setupRestoreSave = readBitReturn('0080');
data.remote = readBitReturn('0100');
data.inputAttenuatorAuto = readBitReturn('0200');
data.inputAttenuatorManual = readBitReturn('0400');



% Process the wavelength
if strncmp(info{1},'~', 1) | strfind(info{1},'SIG')>0
    data.displayReading = 0;
else 
    data.displayReading = str2double(info{1});
end



function nchoose =  readBitReturn(bit)
    nchoose = bitand(hex2dec(info{2}), hex2dec(bit))==hex2dec(bit);
end

end